@@ -18,7 +18,7 @@
  * @author     Adam Ashley <aashley@php.net>
  * @copyright  2001-2006 The PHP Group
  * @license    http://www.php.net/license/3_01.txt  PHP License 3.01
- * @version    CVS: $Id: MDB2.php,v 1.22 2007/06/12 03:11:26 aashley Exp $
+ * @version    CVS: $Id: MDB2.php,v 1.24 2008/04/04 07:57:02 aashley Exp $
  * @link       http://pear.php.net/package/Auth
  * @since      File available since Release 1.3.0
  */
@@ -44,7 +44,7 @@ require_once 'MDB2.php';
  * @author     Adam Ashley <aashley@php.net>
  * @copyright  2001-2006 The PHP Group
  * @license    http://www.php.net/license/3_01.txt  PHP License 3.01
- * @version    Release: 1.5.4  File: $Revision: 1.22 $
+ * @version    Release: 1.6.1  File: $Revision: 1.24 $
  * @link       http://pear.php.net/package/Auth
  * @since      Class available since Release 1.3.0
  */
@@ -131,7 +131,14 @@ class Auth_Container_MDB2 extends Auth_Container
         }
 
         if ($this->options['auto_quote']) {
-            $this->options['final_table'] = $this->db->quoteIdentifier($this->options['table'], true);
+            if (strpos('.', $this->options['table']) === false) {
+                $this->options['final_table'] = $this->db->quoteIdentifier($this->options['table'], true);
+            } else {
+                $t = explode('.', $this->options['table']);
+                for ($i = 0, $count = count($t); $i < $count; $i++)
+                    $t[$i] = $this->db->quoteIdentifier($t[$i], true);
+                $this->options['final_table'] = implode('.', $t);
+            }
             $this->options['final_usernamecol'] = $this->db->quoteIdentifier($this->options['usernamecol'], true);
             $this->options['final_passwordcol'] = $this->db->quoteIdentifier($this->options['passwordcol'], true);
         } else {
